Function discover_new_messages
pub unconstrained fn discover_new_messages<Env>(
contract_address: AztecAddress,
compute_note_hash_and_nullifier: ComputeNoteHashAndNullifier<Env>,
)
pub unconstrained fn discover_new_messages<Env>(
contract_address: AztecAddress,
compute_note_hash_and_nullifier: ComputeNoteHashAndNullifier<Env>,
)
Performs the message discovery process, in which private are downloaded and inspected to find new private notes, partial notes and events, etc., and pending partial notes are processed to search for their completion logs. This is the mechanism via which a contract updates its knowledge of its private state.
Receives the address of the contract on which discovery is performed along with its
compute_note_hash_and_nullifierfunction.